/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react'
import LoadingSpinner from '../../LoadingSpinner.js'
import Template from '../PanelComponents/TemplateRecurso.js'
import PanelTemplateColecao from '../PanelComponents/TemplateColecao.js'
import { fetchAllRequest, getRequest } from '../../HelperFunctions/getAxiosConfig'

export default function TabPanelFavoritos(props) {
    const [loading, handleLoading] = useState(true)

    const [likedLearnObjs, setlikedLearnObjs] = useState([])
    const [likedCollections, setlikedCollections] = useState([])
    const [currLimitLearnObjLiked, setCurrLimitLearnObjLiked] = useState(4);
    const [currLimitCollLiked, setcurrLimitCollLiked] = useState(4);


    const [loadingMoreLearnObj, setLoadingMoreLearnObj] = useState(false)
    const [loadingMoreColl, setLoadingMoreColl] = useState(false)

    const [endOfLearnObj, setEndofLearndObj] = useState(false)
    const [endOfColl, setEndoffColl] = useState(false)


    function handleSuccess(responseArr) {
        setlikedLearnObjs(responseArr[0])
        setlikedCollections(responseArr[1])

        handleLoading(false)
    }

    useEffect(() => {
        handleLoading(true);
        const urls = [
            `/users/${props.id}/learning_objects/liked?offset=0&limit=4`,
            `/users/${props.id}/collections/liked?offset=0&limit=4`
        ]

        fetchAllRequest(urls, handleSuccess, (error) => { console.log(error) })

    }, [])

    const showMoreLikedLearnObj = (limite) => {
        setLoadingMoreLearnObj(true);
        const limit = limite;
        setCurrLimitLearnObjLiked(currLimitLearnObjLiked + limit)
        const url = `/users/${props.id}/learning_objects/liked?offset=${currLimitLearnObjLiked}&limit=${limit}`;
        getRequest(url,
            (data) => {
                if (data.length >= 1) {
                    let currData = [...likedLearnObjs];
                    currData = [...currData.concat(data)];
                    setLoadingMoreLearnObj(false);
                    setlikedLearnObjs(currData);
                }
                else {
                    setLoadingMoreLearnObj(false);
                    setEndofLearndObj(true)
                }
            },
            (error) => { console.log(error) }
        )
    }

    const showMoreLikedCollections = (limite) => {
        const limit = limite;
        setLoadingMoreColl(true);
        setcurrLimitCollLiked(currLimitCollLiked + limit);
        const url = `/users/${props.id}/collections/liked?offset=${currLimitCollLiked}&limit=${limit}`;
        getRequest(url,
            (data) => {
                if (data.length >= 1) {
                    let currData = [...likedCollections];
                    currData = [...currData.concat(data)];
                    setLoadingMoreColl(false);
                    setlikedCollections(currData);
                }
                else {
                    setLoadingMoreColl(false);
                    setEndoffColl(true)
                }
            },
            (error) => { console.log(error) }
        )
    }

    return (
        <>
            {
                loading ?
                    (
                        <LoadingSpinner text={'CARREGANDO...'} />
                    )
                    :
                    (
                        [
                            <React.Fragment>
                                <Template
                                    length={likedLearnObjs.length}
                                    titleText={"Recursos Favoritados"}
                                    noContentText={<p style={{ fontFamily: "Roboto", fontSize: "16px" }}>Quando você favorita um recurso ele aparece nesta seção. Além disso, você
                            <br />
                            aumenta o prestígio dele na Plataforma. Para favoritar, basta clicar no ícone de
                            <br />
                            coração que aparece nos Recursos.
                            </p>}
                                    slice={likedLearnObjs}
                                    showMore={showMoreLikedLearnObj}
                                    loadingMore={loadingMoreLearnObj}
                                    end={endOfLearnObj}
                                />

                                <PanelTemplateColecao
                                    title={"Coleções favoritadas"}
                                    length={likedCollections.length}
                                    noContentText={"Você ainda não curtiu nenhuma coleção."}
                                    sliceArr={likedCollections}
                                    showMore={showMoreLikedCollections}
                                    loadingMore={loadingMoreColl}
                                    end={endOfColl}
                                    followed={false}
                                />
                            </React.Fragment>
                        ]
                    )
            }
        </>
    )
}
